/** 
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.activemq.usecases;

import java.io.File;
import java.io.IOException;

import org.apache.derby.jdbc.EmbeddedDataSource;
import org.activemq.io.impl.DefaultWireFormat;
import org.activemq.store.PersistenceAdapter;
import org.activemq.store.jdbc.JDBCPersistenceAdapter;
import org.activemq.store.journal.JournalPersistenceAdapter;

/**
 * @version $Revision: 1.1.1.1 $
 */
public class JournalDurableSubscriptionTest extends DurableSubscriptionTestSupport {

    boolean init;
    
    protected PersistenceAdapter createPersistenceAdapter() throws IOException {
        
        EmbeddedDataSource ds = new EmbeddedDataSource();
        ds.setDatabaseName("testdb");
        if( !init )
            ds.setCreateDatabase("create");
        JDBCPersistenceAdapter jdbcAdapter = new JDBCPersistenceAdapter(ds, new DefaultWireFormat());
        if( !init )
            jdbcAdapter.setDropTablesOnStartup(true);

        File directory = new File("target/journal");
        if( !init )
            recursiveDelete(directory);
        
        JournalPersistenceAdapter journalAdapter = new JournalPersistenceAdapter(directory, jdbcAdapter);
        journalAdapter.setJournalType(JournalPersistenceAdapter.DEFAULT_JOURNAL_TYPE);
        
        init=true;
        return journalAdapter;
    }
    
}
