/**
 * 
 * Copyright 2004 Protique Ltd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 * 
 **/
package org.activemq;

import javax.jms.JMSException;
import javax.jms.Session;
import javax.jms.XAConnection;
import javax.jms.XAQueueConnection;
import javax.jms.XAQueueSession;
import javax.jms.XASession;
import javax.jms.XATopicConnection;
import javax.jms.XATopicSession;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.activemq.transport.TransportChannel;

/**
 * The XAConnection interface extends the capability of Connection by providing
 * an XASession (optional).
 * <p/>
 * The XAConnection interface is optional. JMS providers are not required to
 * support this interface. This interface is for use by JMS providers to
 * support transactional environments. Client programs are strongly encouraged
 * to use the transactional support  available in their environment, rather
 * than use these XA  interfaces directly.
 *
 * @version $Revision: 1.1.1.1 $
 * @see javax.jms.Connection
 * @see javax.jms.ConnectionFactory
 * @see javax.jms.QueueConnection
 * @see javax.jms.TopicConnection
 * @see javax.jms.TopicConnectionFactory
 * @see javax.jms.QueueConnection
 * @see javax.jms.QueueConnectionFactory
 */
public class ActiveMQXAConnection extends ActiveMQConnection implements XATopicConnection, XAQueueConnection, XAConnection {

    private static final Log log = LogFactory.getLog(ActiveMQXAConnection.class);

	public ActiveMQXAConnection(ActiveMQConnectionFactory factory, String theUserName, String thePassword, TransportChannel transportChannel) throws JMSException {
        super(factory, theUserName, thePassword, transportChannel);
    }

    public ActiveMQXAConnection(ActiveMQConnectionFactory factory, String theUserName, String thePassword) throws JMSException {
        super(factory, theUserName, thePassword);
    }

    public XASession createXASession() throws JMSException {
        return (XASession) createSession(true, Session.SESSION_TRANSACTED);
    }

    public XATopicSession createXATopicSession() throws JMSException {
        return (XATopicSession) createSession(true, Session.SESSION_TRANSACTED);
    }

    public XAQueueSession createXAQueueSession() throws JMSException {
        return (XAQueueSession) createSession(true, Session.SESSION_TRANSACTED);
    }

    public Session createSession(boolean transacted, int acknowledgeMode) throws JMSException {
        checkClosed();
        sendConnectionInfoToBroker();
        return new ActiveMQXASession(this, Session.SESSION_TRANSACTED);
    }
}